# Golden Paths

[![Coverage Status](https://coveralls.io/repos/github/Start-Out/golden-paths/badge.svg?branch=dev)](https://coveralls.io/github/Start-Out/golden-paths?branch=dev)

## StartOut-Supported Paths (official)

### Web

- [postgresql-express-react](https://github.com/Start-Out/path-postgresql-express-react)
